=======
Credits
=======

Development Lead
----------------

* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_

Co-Developers
-------------

None yet. Why not be the first?

Contributors
------------

None yet. Why not be the first?
